@@ -336,8 +336,8 @@ EX(CMD_checktime,	"checktime",	ex_checktime,
 			RANGE|BUFNAME|COUNT|EXTRA|TRLBAR,
 			ADDR_OTHER),
 EX(CMD_chistory,	"chistory",	qf_history,
-			TRLBAR,
-			ADDR_NONE),
+			RANGE|COUNT|TRLBAR,
+			ADDR_UNSIGNED),
 EX(CMD_clist,		"clist",	qf_list,
 			BANG|EXTRA|TRLBAR|CMDWIN,
 			ADDR_NONE),
@@ -828,8 +828,8 @@ EX(CMD_lhelpgrep,	"lhelpgrep",	ex_helpgrep,
 			EXTRA|NOTRLCOM|NEEDARG,
 			ADDR_NONE),
 EX(CMD_lhistory,	"lhistory",	qf_history,
-			TRLBAR,
-			ADDR_NONE),
+			RANGE|COUNT|TRLBAR,
+			ADDR_UNSIGNED),
 EX(CMD_ll,		"ll",		ex_cc,
 			RANGE|COUNT|TRLBAR|BANG,
 			ADDR_QUICKFIX),
@@ -1091,6 +1091,9 @@ EX(CMD_pop,		"pop",		ex_tag,
 EX(CMD_popup,		"popup",	ex_popup,
 			NEEDARG|EXTRA|BANG|TRLBAR|NOTRLCOM|CMDWIN,
 			ADDR_NONE),
+EX(CMD_popupclear,	"popupclear",	ex_popupclear,
+			TRLBAR,
+			ADDR_NONE),
 EX(CMD_ppop,		"ppop",		ex_ptag,
 			RANGE|BANG|COUNT|TRLBAR|ZEROR,
 			ADDR_OTHER),
@@ -1739,6 +1742,9 @@ EX(CMD_xnoremap,	"xnoremap",	ex_map,
 EX(CMD_xnoremenu,	"xnoremenu",	ex_menu,
 			RANGE|ZEROR|EXTRA|TRLBAR|NOTRLCOM|USECTRLV|CMDWIN,
 			ADDR_OTHER),
+EX(CMD_xrestore,	"xrestore",	ex_xrestore,
+			EXTRA|TRLBAR|CMDWIN,
+			ADDR_NONE),
 EX(CMD_xunmap,		"xunmap",	ex_unmap,
 			EXTRA|TRLBAR|NOTRLCOM|USECTRLV|CMDWIN,
 			ADDR_NONE),
