@@ -691,7 +691,7 @@ ui_breakcheck_force(int force)
     if (save_updating_screen)
 	updating_screen = TRUE;
     else
-	reset_updating_screen(FALSE);
+	after_updating_screen(FALSE);
 
     recursive = FALSE;
 }
@@ -1514,7 +1514,7 @@ clip_copy_modeless_selection(int both UNUSED)
 	len *= 2;	/* max. 2 bytes per display cell */
     else if (enc_utf8)
 	len *= MB_MAXBYTES;
-    buffer = lalloc((long_u)len, TRUE);
+    buffer = alloc(len);
     if (buffer == NULL)	    /* out of memory */
 	return;
 
@@ -1897,11 +1897,11 @@ get_input_buf(void)
     garray_T	*gap;
 
     /* We use a growarray to store the data pointer and the length. */
-    gap = (garray_T *)alloc((unsigned)sizeof(garray_T));
+    gap = ALLOC_ONE(garray_T);
     if (gap != NULL)
     {
 	/* Add one to avoid a zero size. */
-	gap->ga_data = alloc((unsigned)inbufcount + 1);
+	gap->ga_data = alloc(inbufcount + 1);
 	if (gap->ga_data != NULL)
 	    mch_memmove(gap->ga_data, inbuf, (size_t)inbufcount);
 	gap->ga_len = inbufcount;
